==> haskell-tamarin-prover-theory-1.4.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.4.1
id: tamarin-prover-theory-1.4.1-LMebA4dmnklJ0D4KB4aAjO
key: tamarin-prover-theory-1.4.1-LMebA4dmnklJ0D4KB4aAjO
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Security protocol types and constraint solver library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
abi: ea5300c007913458c913918e1d1db419
exposed: True
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.Heuristics
    Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.System Theory.Constraint.System.Constraints
    Theory.Constraint.System.Dot Theory.Constraint.System.Guarded
    Theory.Constraint.System.JSON Theory.Model Theory.Model.Atom
    Theory.Model.Fact Theory.Model.Formula Theory.Model.Rule
    Theory.Model.Signature Theory.Proof Theory.Text.Parser
    Theory.Text.Parser.Token Theory.Text.Pretty
    Theory.Tools.AbstractInterpretation Theory.Tools.EquationStore
    Theory.Tools.InjectiveFactInstances Theory.Tools.IntruderRules
    Theory.Tools.LoopBreakers Theory.Tools.RuleVariants
    Theory.Tools.Wellformedness
import-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-theory-1.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-theory-1.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tamarin-prover-theory-1.4.1
hs-libraries: HStamarin-prover-theory-1.4.1-LMebA4dmnklJ0D4KB4aAjO
depends:
    aeson-1.4.4.0-9moDvIlHQnK9lMsbTeXq9U
    aeson-pretty-0.8.7-7HuDaXz8opMAclrfFYGjE5 base-4.12.0.0
    binary-0.8.6.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 dlist-0.8.0.6-3oiqUM21lb56uBENX2Ic5f
    fclabels-2.0.3.3-4pyYMRW7ZpR7Wol7ycOt3l mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ parsec-3.1.13.0
    process-1.6.5.0 safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    tamarin-prover-term-1.4.1-T2lg3is6VN392bVyuHC9D
    tamarin-prover-utils-1.4.1-HdTFWnyCZEB8cEcLgvakeq text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-AdCQY31cIAG4qqUszyKUMy
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-theory-1.4.1-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.4.1
id: tamarin-prover-theory-1.4.1-33iNR3hY0ZZ93rS9xETbeL
key: tamarin-prover-theory-1.4.1-33iNR3hY0ZZ93rS9xETbeL
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Security protocol types and constraint solver library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
abi: d26600cbcf2dc4741f322cfa7953eb58
exposed: True
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.Heuristics
    Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.System Theory.Constraint.System.Constraints
    Theory.Constraint.System.Dot Theory.Constraint.System.Guarded
    Theory.Constraint.System.JSON Theory.Model Theory.Model.Atom
    Theory.Model.Fact Theory.Model.Formula Theory.Model.Rule
    Theory.Model.Signature Theory.Proof Theory.Text.Parser
    Theory.Text.Parser.Token Theory.Text.Pretty
    Theory.Tools.AbstractInterpretation Theory.Tools.EquationStore
    Theory.Tools.InjectiveFactInstances Theory.Tools.IntruderRules
    Theory.Tools.LoopBreakers Theory.Tools.RuleVariants
    Theory.Tools.Wellformedness
import-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-theory-1.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tamarin-prover-theory-1.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tamarin-prover-theory-1.4.1
hs-libraries: HStamarin-prover-theory-1.4.1-33iNR3hY0ZZ93rS9xETbeL
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    aeson-pretty-0.8.7-838zED1kTY32KvMOfvofJe base-4.12.0.0
    binary-0.8.6.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 dlist-0.8.0.6-9UgEeUYmxlQ4pf6zqiW0es
    fclabels-2.0.3.3-4pyYMRW7ZpR7Wol7ycOt3l mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ parsec-3.1.13.0
    process-1.6.5.0 safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    tamarin-prover-term-1.4.1-AOqAgHHCNi8IpTTTYnOOp
    tamarin-prover-utils-1.4.1-CqN0dnN3XLs6WUPpiZ5Bxx text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-GHnr6VZCTqId8dp50AILB
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
